==> jc-1.4.0.tar.gz: gnu/java/net/GetLocalHostAction.h <==
// public class gnu.java.net.GetLocalHostAction

// class file dependencies
// @dep_class 985e0f9a29adf9b2 gnu_java_net_GetLocalHostAction
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_GetLocalHostAction_H_
#define _JC_gnu_java_net_GetLocalHostAction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_net_GetLocalHostAction$sub_refs	_jc_gnu_java_net_GetLocalHostAction$sub_refs;
typedef struct _jc_gnu_java_net_GetLocalHostAction$sub_nonrefs	_jc_gnu_java_net_GetLocalHostAction$sub_nonrefs;
typedef struct _jc_gnu_java_net_GetLocalHostAction$refs	_jc_gnu_java_net_GetLocalHostAction$refs;
typedef struct _jc_gnu_java_net_GetLocalHostAction$nonrefs	_jc_gnu_java_net_GetLocalHostAction$nonrefs;
typedef struct _jc_gnu_java_net_GetLocalHostAction$object	_jc_gnu_java_net_GetLocalHostAction$object;

typedef const struct _jc_gnu_java_net_GetLocalHostAction$vmethods	_jc_gnu_java_net_GetLocalHostAction$vmethods;
typedef const struct _jc_gnu_java_net_GetLocalHostAction$vtable	_jc_gnu_java_net_GetLocalHostAction$vtable;
typedef const struct _jc_gnu_java_net_GetLocalHostAction$vtype	_jc_gnu_java_net_GetLocalHostAction$vtype;

// Constructors
extern void _jc_gnu_java_net_GetLocalHostAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_GetLocalHostAction$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_net_GetLocalHostAction$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_gnu_java_net_GetLocalHostAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_net_GetLocalHostAction$object *);
};

// Vtable
struct _jc_gnu_java_net_GetLocalHostAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_GetLocalHostAction$vmethods	gnu_java_net_GetLocalHostAction;
};

// Vtype
struct _jc_gnu_java_net_GetLocalHostAction$vtype {
	_jc_type			type;
	_jc_gnu_java_net_GetLocalHostAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_GetLocalHostAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_GetLocalHostAction$refs {
    _jc_gnu_java_net_GetLocalHostAction$sub_refs	gnu_java_net_GetLocalHostAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_GetLocalHostAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_GetLocalHostAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_GetLocalHostAction$sub_nonrefs	gnu_java_net_GetLocalHostAction;
};

// Object instance structure
struct _jc_gnu_java_net_GetLocalHostAction$object {
	_jc_gnu_java_net_GetLocalHostAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_GetLocalHostAction$vtype	*vtype;
	_jc_gnu_java_net_GetLocalHostAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_GetLocalHostAction$vtype _jc_gnu_java_net_GetLocalHostAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_GetLocalHostAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_GetLocalHostAction$class_object;

#endif	/* _JC_gnu_java_net_GetLocalHostAction_H_ */

==> jc-1.4.6.tar.gz: gnu/java/net/GetLocalHostAction.h <==
// public class gnu.java.net.GetLocalHostAction

// class file dependencies
// @dep_class 985e0f9a29adf9b2 gnu_java_net_GetLocalHostAction
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_java_net_GetLocalHostAction_H_
#define _JC_gnu_java_net_GetLocalHostAction_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_net_GetLocalHostAction$sub_refs	_jc_gnu_java_net_GetLocalHostAction$sub_refs;
typedef struct _jc_gnu_java_net_GetLocalHostAction$sub_nonrefs	_jc_gnu_java_net_GetLocalHostAction$sub_nonrefs;
typedef struct _jc_gnu_java_net_GetLocalHostAction$refs	_jc_gnu_java_net_GetLocalHostAction$refs;
typedef struct _jc_gnu_java_net_GetLocalHostAction$nonrefs	_jc_gnu_java_net_GetLocalHostAction$nonrefs;
typedef struct _jc_gnu_java_net_GetLocalHostAction$object	_jc_gnu_java_net_GetLocalHostAction$object;

typedef const struct _jc_gnu_java_net_GetLocalHostAction$vmethods	_jc_gnu_java_net_GetLocalHostAction$vmethods;
typedef const struct _jc_gnu_java_net_GetLocalHostAction$vtable	_jc_gnu_java_net_GetLocalHostAction$vtable;
typedef const struct _jc_gnu_java_net_GetLocalHostAction$vtype	_jc_gnu_java_net_GetLocalHostAction$vtype;

// Constructors
extern void _jc_gnu_java_net_GetLocalHostAction$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_net_GetLocalHostAction$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_net_GetLocalHostAction$method$run$b190d7b16d5785b8(_jc_env *, struct _jc_gnu_java_net_GetLocalHostAction$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_net_GetLocalHostAction$method_info$run$b190d7b16d5785b8;

// Virtual methods structure
struct _jc_gnu_java_net_GetLocalHostAction$vmethods {
	struct _jc_java_lang_Object$object	*(*run$b190d7b16d5785b8)(_jc_env *, struct _jc_gnu_java_net_GetLocalHostAction$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_net_GetLocalHostAction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_net_GetLocalHostAction$vmethods	gnu_java_net_GetLocalHostAction;
};

// Vtype
struct _jc_gnu_java_net_GetLocalHostAction$vtype {
	_jc_type			type;
	_jc_gnu_java_net_GetLocalHostAction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_net_GetLocalHostAction$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_net_GetLocalHostAction$refs {
    _jc_gnu_java_net_GetLocalHostAction$sub_refs	gnu_java_net_GetLocalHostAction;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_net_GetLocalHostAction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_net_GetLocalHostAction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_net_GetLocalHostAction$sub_nonrefs	gnu_java_net_GetLocalHostAction;
};

// Object instance structure
struct _jc_gnu_java_net_GetLocalHostAction$object {
	_jc_gnu_java_net_GetLocalHostAction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_net_GetLocalHostAction$vtype	*vtype;
	_jc_gnu_java_net_GetLocalHostAction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_net_GetLocalHostAction$vtype _jc_gnu_java_net_GetLocalHostAction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_net_GetLocalHostAction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_net_GetLocalHostAction$class_object;

#endif	/* _JC_gnu_java_net_GetLocalHostAction_H_ */
